Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuilderSupport ¶
type BuilderSupport interface {
// AddArgument(string) // must be provided by each directive
AddPreposition(string) // not required by all directives
ColumnSpecifierFromArg(string) *column.Specifier
IsKeyword(string, keyword.ID) bool
KeywordName(keyword.ID) string
}
API provided by the parser to the directive builders, allowing them to perform common tasks such as looking up keywords etc
type ConfigAPI ¶
type ConfigAPI interface {
SetPrefix(string)
SetPrefixPattern(string)
SetProfile(*profile.Profile)
SetLocaleTag(string)
}
API used by directives to perform their actions BEFORE importing data into a table
Click to show internal directories.
Click to hide internal directories.